@@ -15,5 +15,23 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifndef HISTORY_H
+#define HISTORY_H
+
+#include <qdialog.h>
+#include <qmultilineedit.h>
+#include "../libgadu/lib/libgadu.h"
+
+class History : public QDialog {
+    Q_OBJECT
+    public:
+	History(uin_t);
+
+    protected:
+	QMultiLineEdit *body;
+};
+
 char *timestamp(time_t = 0);
 void appendHistory(unsigned int uin, unsigned char * msg, bool, time_t = 0);
+
+#endif
